ipsec whack --impair timeout_on_retransmit
# this should fail
ipsec auto --up san
echo "done"
